# -*- coding: utf-8 -*-
# pylint: disable=bad-whitespace
# flake8: noqa
"""
    JS Invoke Lib – Project automation library for invoke.
    Copyright ©  2017 Justin Stout <justin@jstout.us>
"""
from __future__ import absolute_import, print_function

from invoke import run
from invoke import task

from os.path import join as join_path

from js_invoke_lib.core import get_project_info

def _clean(generated=False, bytecode=False, extra=''):
    patterns = []
    project_info = get_project_info()
    pkg_name = project_info['pkg_name']

    if generated:
        patterns.append('/vagrant/src/{}/build/*'.format(pkg_name))
        patterns.append('/vagrant/src/{}/dist/*'.format(pkg_name))
        patterns.append('/vagrant/src/{}/{}.egg-info'.format(pkg_name, pkg_name))

    for pattern in patterns:
        run('rm -rf {}'.format(pattern))

    if bytecode:
        run("find * -name '*.pyc' | xargs rm -f")

@task
def clean():
    """
    clean bytecode
    """
    _clean(bytecode=True)

@task(clean)
def cleaner():
    """
    clean bytecode and generated files
    """
    _clean(generated=True)

@task(cleaner)
def cleanest():
    """
    Not implemented
    """
    pass

@task
def build():
    """
    Build python module
    """

    project_info = get_project_info()
    cmd = "cd /vagrant/src/{} && python setup.py sdist bdist_wheel".format(project_info['pkg_name'])
    run(cmd)
