# -*- coding: utf-8 -*-
# pylint: disable=bad-whitespace
# flake8: noqa
"""
    JS Invoke Lib – Project automation library for invoke.
    Copyright ©  2017 Justin Stout <justin@jstout.us>
"""
from __future__ import absolute_import, print_function

import os
import shutil

from os.path import join as join_path

from invoke import run
from invoke import task

from js_invoke_lib.core import get_project_info

@task
def init_repo():
    """
    Initialize repo and push to git hub
    """
    project_info = get_project_info()

    run('git init')
    run('git add .')
    run('git commit -m "New project from cookie cutter"')

    remote_url = 'git@github.com:{}/{}.git'.format(
        project_info['github_username'],
        project_info['repo_name']
        )

    run('git remote add origin {}'.format(remote_url))

    run('git tag -a "v_0_0_0" -m "cookiecutter ref"')

    run('git checkout -b develop master')

    run('git push -u origin master')
    run('git push -u origin develop')
    run('git push --tags')

@task
def tag_release():
    """
    Tag release and push to get hub
    """
    project_info = get_project_info()

    cmd = 'git tag -a "v_{}" -m "release V {}"'.format(
        project_info['version'].replace('.', '_'),
        project_info['version']
        )

    run(cmd)

    run('git push --tags')

@task(help={'name': "name of new module (ex my_project.new_module)"})
def new_module(name):
    """
    Copy the template module from project.d/templates/module to destination
    """

    mod_src_path = '/vagrant/project.d/templates/module'

    mod_dst_path = join_path(
        '/vagrant/src',
        get_project_info()['pkg_name'],
        name.replace('.', '/')
        )

    shutil.copytree(mod_src_path, mod_dst_path)

@task(help={'name': "name of new class (ex my_project.my_module.class) .py not required"})
def new_class(name):
    """
    Copy the template class from project.d/templates/module to destination
    """
    src_path = '/vagrant/project.d/templates/module/new_class.py'

    dst_path = join_path(
        '/vagrant/src',
        get_project_info()['pkg_name'],
        name.replace('.', '/') + '.py'
        )

    shutil.copy(src_path, dst_path)

@task(help={'name': "name of new test (ex unit.config.test_app) .py not required"})
def new_test(name):
    """
    Copy the template class from project.d/templates/test_module.py
    """
    src_path = '/vagrant/project.d/templates/test_module.py'

    dst_elem = ['/vagrant/src/tests'] + name.split('.')[:-1] + [name.split('.')[-1:][0] + '.py']

    dst_path = join_path(*dst_elem)

    try:
        shutil.copy(src_path, dst_path)

    except IOError:
        dst_dir_elem = dst_elem[:-1]
        os.makedirs(
            join_path(*dst_dir_elem)
            )
        shutil.copy(src_path, dst_path)
