# -*- coding: utf-8 -*-
# pylint: disable=bad-whitespace
# flake8: noqa
"""
    JS Invoke Lib – Project automation library for invoke.
    Copyright ©  2017 Justin Stout <justin@jstout.us>
"""
from __future__ import absolute_import, print_function

import os

from invoke import run
from invoke import task

from os.path import join as join_path

from js_invoke_lib.core import get_project_info
from js_invoke_lib.core import save_project_info
from js_invoke_lib.python import build
from js_invoke_lib.python import dev

def _register_pypi(publish_target):
    """
    publish_dst(str):   Which repo to register with, name matches named in ~/.pypirc
                        Current options: testpypi & pypi
    """
    project_info = get_project_info()
    pkg_name = project_info['pkg_name']
    dist_dir = '/vagrant/src/{}/dist'.format(pkg_name)

    for build_file in os.listdir(dist_dir):
        cmd = "twine register -r {} {}".format(
            publish_target,
            join_path(dist_dir, build_file)
            )

        run(cmd)

def _upload_to_pypi(publish_target):
    """
    publish_dst(str):   Which repo to register with, name matches named in ~/.pypirc
                        Current options: testpypi & pypi
    """
    project_info = get_project_info()
    pkg_name = project_info['pkg_name']
    dist_dir = '/vagrant/src/{}/dist'.format(pkg_name)

    for build_file in os.listdir(dist_dir):
        cmd = "twine upload -r {} {}".format(
            publish_target,
            join_path(dist_dir, build_file)
            )

        run(cmd)

def _bump_version(current, part, pkg_name):
    cmd_base = "bumpversion --current-version {} {} ".format(current, part)

    run(cmd_base + '/vagrant/project.d/project_info.json')
    run(cmd_base + ' --allow-dirty ' + '/vagrant/src/{}/{}/__init__.py'.format(pkg_name, pkg_name))
    run(cmd_base + ' --allow-dirty ' + '/vagrant/src/{}/setup.py'.format(pkg_name))

@task(help={'release_type': "release type: major, minor, patch"})
def release(release_type):
    """
    cleaner(), bump version, build module

    - verify that we are on master branch
    - verify no unstaged files              <DONE>
    - cleaner()                             <DONE>
    - bump version                          <DONE>
    - tag repo and push to github           <DONE>
    - build module                          <DONE>
    - build docs
    - build reports
    - ?
    """
    if not release_type in ['major', 'minor', 'patch']:
        print('Invalid release type: {}'.format(release_type))
        return

    project_info = get_project_info()

    build.cleaner()

    _bump_version(
        project_info['version'],
        release_type,
        project_info['pkg_name']
        )

    project_info = get_project_info()

    #add bump version files to commit
    run('git add .')
    run('git commit -m "bump version to {}"'.format(project_info['version']))

    dev.tag_release()

    build.build()

@task()
def publish():
    """
    Publish generated files to the desired repo, and register project if required.
    """
    is_reg_path = '/vagrant/project.d/registered_pypi'

    project_info = get_project_info()

    _upload_to_pypi(project_info['publish_target'])
