# -*- coding: utf-8 -*-
# pylint: disable=bad-whitespace
# flake8: noqa
"""
    JS Invoke Lib – Project automation library for invoke.
    Copyright ©  2017 Justin Stout <justin@jstout.us>
"""
from __future__ import absolute_import, print_function

import os

from os.path import join as join_path

from invoke import run
from invoke import task

from js_invoke_lib.core import get_project_info

def _get_base_path(root, module):
    """
    Determine correct base path
    We can have:  blank line - test all
                  directory  - test all in module
                  file       - test a single class/file
    """
    project_info = get_project_info()

    base_path = join_path(
        '/vagrant',
        root,
        project_info['pkg_name'],
        project_info['pkg_name']
        )

    if module:
        base_path = join_path(
            base_path,
            module.replace('.', '/')
            )

    if os.path.isfile(base_path + '.py'):
        base_path += '.py'

    return base_path

def _run_test(type_, module):
    """
    Run a test package: unit, integration, or system

    params:
        type_(str):     Test package to run ( unit, integration, or system)
        module(str):    Test a single module or file

    Determine correct base path
    We can have:  blank line - test all
                  directory  - test all in module
                  file       - test a single class/file
    """

    project_info = get_project_info()

    python_path = join_path(
        '/vagrant/src',
        project_info['pkg_name']
        )

    base_path = join_path('/vagrant/src/tests', type_)

    if module:
        base_path = join_path(
            base_path,
            module.replace('.', '/')
            )

    if os.path.isfile(base_path + '.py'):
        base_path += '.py'

    cmd = "PYTHONPATH='{}' py.test {}".format(python_path, base_path)
    run(cmd)

@task(help={'module': "name of module to test (ex my_module or my_module.my_class) (default = all)"})
def pylint(module=None):
    """
    run pylint in errors-only mode

    Determine correct base path
    We can have:  blank line - test all
                  directory  - test all in module
                  file       - test a single class/file
    """
    project_info = get_project_info()

    base_path = join_path(
        '/vagrant',
        root,
        project_info['pkg_name'],
        project_info['pkg_name']
        )

    if module:
        base_path = join_path(
            base_path,
            module.replace('.', '/')
            )

    if os.path.isfile(base_path + '.py'):
        base_path += '.py'

    cmd = "pylint --rcfile=/vagrant/project.d/pylint.cfg --errors-only {}".format(base_path)
    run(cmd)

@task(help={'module': "name of module to test (ex my_project.new_module) (default = all)"})
def unit(module=None):
    _run_test('unit', module)

@task(help={'module': "name of module to test (ex my_project.new_module) (default = all)"})
def integration(module=None):
    _run_test('integration', module)
